 #!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys, os, configparser
from PyQt5 import uic, QtWidgets
from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import (QApplication, QMainWindow, QMessageBox,
	QFileDialog)
 
from help import Ui_Dialog as Help
import helptext
import buildfiles

class MainWindow(QMainWindow):
	def __init__(self):
		super(MainWindow, self).__init__()
		uic.loadUi("7i96.ui", self)

		self.prompt_at_exit = False
		self.useConfigName.setChecked(True)
		self.config = configparser.ConfigParser(strict=False)
		self.config.sections()
		self.configPath = os.path.expanduser('~/linuxcnc/configs')
		self.iniDictionary = {}
		self.setupConnections()
		self.setupApp()
		self.setupMainPage()
		self.helpInfo = helptext.descriptions
		self.statusBar().showMessage('Ready')
		self.saveini = buildfiles.buildini

		self.offsetRelativeRB.toggled[bool].connect(self.onReportedPositionTypeChanged)
		self.offsetMachineRB.toggled[bool].connect(self.onReportedPositionTypeChanged)

		self.show()

	# Auto connected menu action callbacks
	@pyqtSlot()
	def on_actionFileNew_triggered(self):
		print('File New')

	@pyqtSlot()
	def on_actionFileOpen_triggered(self):
		if not os.path.isdir(self.configPath):
			self.configPath = os.path.expanduser('~/')
		fileName = QFileDialog.getOpenFileName(self,
		caption="Select Configuration INI File", directory=self.configPath,
		filter='*.ini', options=QFileDialog.DontUseNativeDialog,)
		if fileName:
			iniFile = (fileName[0])
			self.config.read(iniFile)
			if 'EMC' in self.config:
				print(self.config['EMC']['MACHINE'])
				self.configName.setText(self.config['EMC']['MACHINE'])

	@pyqtSlot()
	def on_actionFileSave_triggered(self):
		if self.saveini(self.iniDictionary):
			self.statusBar().showMessage('Configuration Saved')

	@pyqtSlot()
	def on_actionFileSaveAs_triggered(self):
		 print('File Save As')

	@pyqtSlot()
	def on_actionFileExit_triggered(self):
		 exit()

	@pyqtSlot()
	def on_actionThisTab_triggered(self):
		self.help()
		

	@pyqtSlot(bool)
	def onReportedPositionTypeChanged(self, is_checked):
		button = self.sender()
		if button.isChecked():
			print(button.objectName())

	@pyqtSlot()
	def on_actionHelpAbout_triggered(self):
		msg = QMessageBox(parent)
		msg.setIcon(QMessageBox.Information)

		msg.setText("This is a message box")
		msg.setInformativeText("This is additional information")
		msg.setWindowTitle("MessageBox demo")
		msg.setDetailedText("The details are as follows:")
		msg.setStandardButtons(QMessageBox.Ok | QMessageBox.Cancel)
		#msg.buttonClicked.connect(msgbtn)
		retval = msg.exec_()
		if retval == QMessageBox.Ok:
			print('yes')
		print("value of pressed message box button: {}".format(retval))
		#QMessageBox.about(None, "7i96 Configuration Wizard", "Message")

	@pyqtSlot()
	def on_actionExit_triggered(self):
		self.close()

	def setupConnections(self):
		self.displayHelp_0.clicked.connect(self.help)
		self.displayHelp_1.clicked.connect(self.help)
		self.displayHelp_2.clicked.connect(self.help)
		self.displayHelp_3.clicked.connect(self.help)
		self.displayHelp_4.clicked.connect(self.help)
		self.displayHelp_5.clicked.connect(self.help)
		self.configName.textChanged[str].connect(self.onLineEditChanged)


	def setupMainPage(self):
		# change the data to be just the value and add custome property for section & item
		self.debugCombo.addItem("Debug Off", ['0x00000000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Configuration", ['0x00000002', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Task Issues", ['0x00000008', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug NML", ['0x00000010', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Motion Time", ['0x00000040', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Interpreter", ['0x00000080', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug RCS", ['0x00000100', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Interperter List", ['0x00000800', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug IO Control", ['0x00001000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug O Word", ['0x00002000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Remap", ['0x00004000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Python", ['0x00008000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Named Parameters", ['0x00010000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Gdbon Signal", ['0x00020000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Python Task", ['0x00040000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug User 1", ['0x10000000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug User 2", ['0x20000000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug Unconditional", ['0x40000000', 'EMC', 'DEBUG'])
		self.debugCombo.addItem("Debug All", ['0x7FFFFFFF', 'EMC', 'DEBUG'])
		self.debugCombo.activated.connect(self.onComboActivated)

		self.guiCombo.addItem('Select a GUI', ['', '', ''])
		self.guiCombo.addItem('Axis', ['axis', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Touchy', ['touchy', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Gmoccapy', ['gmoccapy', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Gscreen', ['gscreen', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Keystick', ['keystick', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Mini', ['mini', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Tklinuxcnc', ['tklinuxcnc', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.addItem('Xemc', ['xemc', 'DISPLAY', 'DISPLAY'])
		self.guiCombo.activated.connect(self.onComboActivated)

	def onComboActivated(self, index):
		# update the iniDictionary when ever something changes
		iniSetting = self.sender().currentData()[0]
		iniSection = self.sender().currentData()[1]
		iniItem = self.sender().currentData()[2]
		self.iniDictionary[iniSection][iniItem] = [iniSetting]
		#print('Variable {}'.format(self.sender().itemData(index)[0]))
		#print('Section {}'.format(self.sender().itemData(index)[1]))
		#print('Item {}'.format(self.sender().itemData(index)[2]))
		#print(self.iniDictionary)
		#print(self.sender().objectName())
		#print(self.sender().currentText())
		#print(self.sender().currentData())

	def onLineEditChanged(self, text):
		# update the iniDictionary when text is changed
		section = self.sender().property("iniSection")
		item = self.sender().property('iniItem')
		self.iniDictionary[section][item] = text
		if self.sender().objectName() == 'configName':
			self.pathLabel.setText(self.configPath + '/' + text)
		

	def setupApp(self):
		# move this to another file cause it will be big when done
		self.iniDictionary['EMC'] = {}
		self.iniDictionary['EMC']['MACHINE'] = ''
		self.iniDictionary['EMC']['DEBUG'] = ''
		self.iniDictionary['DISPLAY'] = {}
		self.iniDictionary['DISPLAY']['DISPLAY'] = ''
		self.iniDictionary['FILTER'] = {}
		self.iniDictionary['TASK'] = {}
		self.iniDictionary['RS274NGC'] = {}
		self.iniDictionary['EMCMOT'] = {}
		self.iniDictionary['HOSTMOT2'] = {}
		self.iniDictionary['HAL'] = {}
		self.iniDictionary['HALUI'] = {}
		self.iniDictionary['TRAJ'] = {}
		self.iniDictionary['EMCIO'] = {}
		self.iniDictionary['AXIS_0'] = {}
		self.iniDictionary['AXIS_1'] = {}
		self.iniDictionary['AXIS_2'] = {}
		self.iniDictionary['AXIS_3'] = {}
		self.iniDictionary['AXIS_4'] = {}
		self.iniDictionary['AXIS_5'] = {}
		self.iniDictionary['AXIS_6'] = {}
		self.iniDictionary['AXIS_7'] = {}
		self.iniDictionary['AXIS_8'] = {}
		self.iniDictionary['JOINT_0'] = {}
		self.iniDictionary['JOINT_1'] = {}
		self.iniDictionary['JOINT_2'] = {}
		self.iniDictionary['JOINT_3'] = {}
		self.iniDictionary['JOINT_4'] = {}
		self.iniDictionary['JOINT_5'] = {}
		self.iniDictionary['JOINT_6'] = {}
		self.iniDictionary['JOINT_7'] = {}
		self.iniDictionary['JOINT_8'] = {}
		self.iniDictionary['SPINDLE'] = {}

	def help(self):
		dialog = QtWidgets.QDialog()
		dialog.ui = Help()
		dialog.ui.setupUi(dialog)
		dialog.ui.label.setText(self.helpInfo(self.tabWidget.currentIndex()))
		dialog.exec_()
		

if __name__ == "__main__":
	app = QApplication(sys.argv)
	ex = MainWindow()
	sys.exit(app.exec_())
